@@ -1,37 +1,29 @@
 from functools import update_wrapper
+from functools import partial
 from inspect import signature, Parameter
+import logging
 
 from parsl.app.errors import wrap_error
 from parsl.app.app import AppBase
 from parsl.dataflow.dflow import DataFlowKernelLoader
 
+logger = logging.getLogger(__name__)
+
 
 def remote_side_bash_executor(func, *args, **kwargs):
     """Executes the supplied function with *args and **kwargs to get a
     command-line to run, and then run that command-line using bash.
     """
     import os
-    import time
     import subprocess
-    import logging
     import parsl.app.errors as pe
-    from parsl import set_file_logger
     from parsl.utils import get_std_fname_mode
 
-    logbase = "/tmp"
-    format_string = "%(asctime)s.%(msecs)03d %(name)s:%(lineno)d [%(levelname)s]  %(message)s"
-
-    # make this name unique per invocation so that each invocation can
-    # log to its own file. It would be better to include the task_id here
-    # but that is awkward to wire through at the moment as apps do not
-    # have access to that execution context.
-    t = time.time()
-
-    logname = __name__ + "." + str(t)
-    logger = logging.getLogger(logname)
-    set_file_logger(filename='{0}/bashexec.{1}.log'.format(logbase, t), name=logname, level=logging.DEBUG, format_string=format_string)
-
-    func_name = func.__name__
+    if hasattr(func, '__name__'):
+        func_name = func.__name__
+    else:
+        logger.warning('No name for the function. Potentially a result of parsl#2233')
+        func_name = 'bash_app'
 
     executable = None
 
@@ -40,6 +32,9 @@ def remote_side_bash_executor(func, *args, **kwargs):
         # Execute the func to get the commandline
         executable = func(*args, **kwargs)
 
+        if not isinstance(executable, str):
+            raise ValueError(f"Expected a str for bash_app commandline, got {type(executable)}")
+
     except AttributeError as e:
         if executable is not None:
             raise pe.AppBadFormatting("App formatting failed for app '{}' with AttributeError: {}".format(func_name, e))
@@ -49,11 +44,8 @@ def remote_side_bash_executor(func, *args, **kwargs):
     except IndexError as e:
         raise pe.AppBadFormatting("App formatting failed for app '{}' with IndexError: {}".format(func_name, e))
     except Exception as e:
-        logger.error("Caught exception during formatting of app '{}': {}".format(func_name, e))
         raise e
 
-    logger.debug("Executable: %s", executable)
-
     # Updating stdout, stderr if values passed at call time.
 
     def open_std_fd(fdname):
@@ -80,12 +72,12 @@ def remote_side_bash_executor(func, *args, **kwargs):
 
     returncode = None
     try:
-        proc = subprocess.Popen(executable, stdout=std_out, stderr=std_err, shell=True, executable='/bin/bash')
+        proc = subprocess.Popen(executable, stdout=std_out, stderr=std_err, shell=True, executable='/bin/bash', close_fds=False)
         proc.wait(timeout=timeout)
         returncode = proc.returncode
 
     except subprocess.TimeoutExpired:
-        raise pe.AppTimeout("[{}] App exceeded walltime: {}".format(func_name, timeout))
+        raise pe.AppTimeout("[{}] App exceeded walltime: {} seconds".format(func_name, timeout))
 
     except Exception as e:
         raise pe.AppException("[{}] App caught exception with returncode: {}".format(func_name, returncode), e)
@@ -123,6 +115,14 @@ class BashApp(AppBase):
             if sig.parameters[s].default is not Parameter.empty:
                 self.kwargs[s] = sig.parameters[s].default
 
+        # update_wrapper allows remote_side_bash_executor to masquerade as self.func
+        # partial is used to attach the first arg the "func" to the remote_side_bash_executor
+        # this is done to avoid passing a function type in the args which parsl.serializer
+        # doesn't support
+        remote_fn = partial(update_wrapper(remote_side_bash_executor, self.func), self.func)
+        remote_fn.__name__ = self.func.__name__
+        self.wrapped_remote_function = wrap_error(remote_fn)
+
     def __call__(self, *args, **kwargs):
         """Handle the call to a Bash app.
 
@@ -145,10 +145,9 @@ class BashApp(AppBase):
         else:
             dfk = self.data_flow_kernel
 
-        app_fut = dfk.submit(wrap_error(update_wrapper(remote_side_bash_executor, self.func)),
-                             app_args=(self.func, *args),
+        app_fut = dfk.submit(self.wrapped_remote_function,
+                             app_args=args,
                              executors=self.executors,
-                             fn_hash=self.func_hash,
                              cache=self.cache,
                              ignore_for_cache=self.ignore_for_cache,
                              app_kwargs=invocation_kwargs)
