@@ -147,7 +147,6 @@ class Interchange(object):
         self.results_outgoing.connect("tcp://{}:{}".format(client_address, client_ports[1]))
 
         self.command_channel = self.context.socket(zmq.REP)
-        self.command_channel.RCVTIMEO = 1000  # in milliseconds
         self.command_channel.connect("tcp://{}:{}".format(client_address, client_ports[2]))
         logger.info("Connected to client")
 
@@ -342,7 +341,6 @@ class Interchange(object):
         start = time.time()
         count = 0
 
-        self._kill_event = threading.Event()
         self._task_puller_thread = threading.Thread(target=self.task_puller,
                                                     name="Interchange-Task-Puller")
         self._task_puller_thread.start()
@@ -351,6 +349,8 @@ class Interchange(object):
                                                 name="Interchange-Command")
         self._command_thread.start()
 
+        kill_event = threading.Event()
+
         poller = zmq.Poller()
         poller.register(self.task_outgoing, zmq.POLLIN)
         poller.register(self.results_incoming, zmq.POLLIN)
@@ -361,7 +361,7 @@ class Interchange(object):
         # onto this list.
         interesting_managers: Set[bytes] = set()
 
-        while not self._kill_event.is_set():
+        while not kill_event.is_set():
             self.socks = dict(poller.poll(timeout=poll_period))
 
             # Listen for requests for work
@@ -402,7 +402,7 @@ class Interchange(object):
                             msg['parsl_v'] != self.current_platform['parsl_v']):
                             logger.error("Manager {} has incompatible version info with the interchange".format(manager_id))
                             logger.debug("Setting kill event")
-                            self._kill_event.set()
+                            kill_event.set()
                             e = VersionMismatch("py.v={} parsl.v={}".format(self.current_platform['python_v'].rsplit(".", 1)[0],
                                                                             self.current_platform['parsl_v']),
                                                 "py.v={} parsl.v={}".format(msg['python_v'].rsplit(".", 1)[0],
