@@ -11,16 +11,14 @@ import threading
 import queue
 import multiprocessing as mp
 
-from ipyparallel.serialize import pack_apply_message, unpack_apply_message
-from ipyparallel.serialize import serialize_object, deserialize_object
-
+from parsl.serialize import serialize, deserialize
+from parsl.serialize import pack_apply_message, unpack_apply_message
 from parsl.executors.status_handling import NoStatusHandlingExecutor
 
 logger = logging.getLogger(__name__)
 
 
 BUFFER_THRESHOLD = 1024 * 1024
-ITEM_THRESHOLD = 1024
 
 
 def runner(incoming_q, outgoing_q):
@@ -131,15 +129,15 @@ def runner(incoming_q, outgoing_q):
                 try:
                     response_obj = execute_task(msg['buffer'])
                     response = {"task_id": msg["task_id"],
-                                "result": serialize_object(response_obj)}
+                                "result": serialize(response_obj)}
 
                     logger.debug("[RUNNER] Returing result: {}".format(
-                                   deserialize_object(response["result"])))
+                                   deserialize(response["result"])))
 
                 except Exception as e:
                     logger.debug("[RUNNER] Caught task exception: {}".format(e))
                     response = {"task_id": msg["task_id"],
-                                "exception": serialize_object(e)}
+                                "exception": serialize(e)}
 
                 outgoing_q.put(response)
 
@@ -258,11 +256,11 @@ class TurbineExecutor(NoStatusHandlingExecutor):
                     logger.debug("[MTHREAD] Received message: {}".format(msg))
                     task_fut = self.tasks[msg['task_id']]
                     if 'result' in msg:
-                        result, _ = deserialize_object(msg['result'])
+                        result, _ = deserialize(msg['result'])
                         task_fut.set_result(result)
 
                     elif 'exception' in msg:
-                        exception, _ = deserialize_object(msg['exception'])
+                        exception, _ = deserialize(msg['exception'])
                         task_fut.set_exception(exception)
 
             if not self.is_alive:
@@ -309,10 +307,10 @@ class TurbineExecutor(NoStatusHandlingExecutor):
 
         Args:
             - func (callable) : Callable function
-            - *args (list) : List of arbitrary positional arguments.
+            - args (list) : List of arbitrary positional arguments.
 
         Kwargs:
-            - **kwargs (dict) : A dictionary of arbitrary keyword args for func.
+            - kwargs (dict) : A dictionary of arbitrary keyword args for func.
 
         Returns:
               Future
@@ -324,8 +322,7 @@ class TurbineExecutor(NoStatusHandlingExecutor):
         self.tasks[task_id] = Future()
 
         fn_buf = pack_apply_message(func, args, kwargs,
-                                    buffer_threshold=1024 * 1024,
-                                    item_threshold=1024)
+                                    buffer_threshold=1024 * 1024)
 
         msg = {"task_id": task_id,
                "buffer": fn_buf}
