@@ -1,5 +1,4 @@
 import logging
-import sys
 import typeguard
 import concurrent.futures as cf
 
@@ -21,7 +20,7 @@ class ThreadPoolExecutor(NoStatusHandlingExecutor, RepresentationMixin):
     max_threads : int
         Number of threads. Default is 2.
     thread_name_prefix : string
-        Thread name prefix (only supported in python v3.6+).
+        Thread name prefix
     storage_access : list of :class:`~parsl.data_provider.staging.Staging`
         Specifications for accessing data this executor remotely.
     managed : bool
@@ -47,11 +46,8 @@ class ThreadPoolExecutor(NoStatusHandlingExecutor, RepresentationMixin):
         self.managed = managed
 
     def start(self):
-        if sys.version_info > (3, 6):
-            self.executor = cf.ThreadPoolExecutor(max_workers=self.max_threads,
-                                                  thread_name_prefix=self.thread_name_prefix)
-        else:
-            self.executor = cf.ThreadPoolExecutor(max_workers=self.max_threads)
+        self.executor = cf.ThreadPoolExecutor(max_workers=self.max_threads,
+                                              thread_name_prefix=self.thread_name_prefix)
 
     @property
     def scaling_enabled(self):
@@ -94,13 +90,24 @@ class ThreadPoolExecutor(NoStatusHandlingExecutor, RepresentationMixin):
 
         raise NotImplementedError
 
-    def shutdown(self, block=False):
-        """Shutdown the ThreadPool.
+    def shutdown(self, block=True):
+        """Shutdown the ThreadPool. The underlying concurrent.futures thread pool
+        implementation will not terminate tasks that are being executed, because it
+        does not provide a mechanism to do that. With block set to false, this will
+        return immediately and it will appear as if the DFK is shut down, but
+        the python process will not be able to exit until the thread pool has
+        emptied out by task completions. In either case, this can be a very long wait.
 
         Kwargs:
             - block (Bool): To block for confirmations or not
 
         """
+        logger.debug("Shutting down executor, which involves waiting for running tasks to complete")
         x = self.executor.shutdown(wait=block)
         logger.debug("Done with executor shutdown")
         return x
+
+    def monitor_resources(self):
+        """Resource monitoring sometimes deadlocks when using threads, so this function
+        returns false to disable it."""
+        return False
