@@ -7,7 +7,7 @@ from string import Template
 from parsl.dataflow.error import ConfigurationError
 from parsl.providers.azure.template import template_string
 from parsl.providers.provider_base import ExecutionProvider, JobState, JobStatus
-from parsl.providers.error import OptionalModuleMissing
+from parsl.errors import OptionalModuleMissing
 from parsl.utils import RepresentationMixin
 from parsl.launchers import SingleNodeLauncher
 
@@ -358,11 +358,6 @@ class AzureProvider(ExecutionProvider, RepresentationMixin):
     def label(self):
         return self._label
 
-    @property
-    def current_capacity(self):
-        """Returns the current blocksize."""
-        return len(self.instances)
-
     def create_nic(self, network_client):
         """Create (or update, if it exists already) a Network Interface for a VM.
 
